==> glib-1.3.2.tar.gz: glib-1.3.2/grand.h <==
/* GLIB - Library of useful routines for C programming
 * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GLib Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GLib at ftp://ftp.gtk.org/pub/gtk/. 
 */

#ifndef __G_RAND_H__
#define __G_RAND_H__

#include <gtypes.h>

G_BEGIN_DECLS

typedef struct _GRand           GRand;

/* GRand - a good and fast random number generator: Mersenne Twister
 * see http://www.math.keio.ac.jp/~matumoto/emt.html for more info.
 * The range functions return a value in the intervall [min,max).
 * int          -> [0..2^32-1]
 * int_range    -> [min..max-1]
 * double       -> [0..1)
 * double_range -> [min..max)
 */

GRand*  g_rand_new_with_seed   (guint32     seed);
GRand*  g_rand_new             (void);
void    g_rand_free            (GRand      *rand);

void    g_rand_set_seed        (GRand      *rand,
                                guint32     seed);
guint32 g_rand_int             (GRand      *rand);
gint32  g_rand_int_range       (GRand      *rand,
                                gint32      min,
                                gint32      max);
gdouble g_rand_double          (GRand      *rand);
gdouble g_rand_double_range    (GRand      *rand,
                                gdouble     min,
                                gdouble     max);

void    g_random_set_seed      (guint32     seed);
guint32 g_random_int           (void);
gint32  g_random_int_range     (gint32      min,
                                gint32      max);
gdouble g_random_double        (void);
gdouble g_random_double_range  (gdouble     min,
                                gdouble     max);

G_END_DECLS

#endif /* __G_RAND_H__ */

==> glib-1.3.3.tar.gz: glib-1.3.3/grand.h <==
/* GLIB - Library of useful routines for C programming
 * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GLib Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GLib at ftp://ftp.gtk.org/pub/gtk/. 
 */

#ifndef __G_RAND_H__
#define __G_RAND_H__

#include <gtypes.h>

G_BEGIN_DECLS

typedef struct _GRand           GRand;

/* GRand - a good and fast random number generator: Mersenne Twister
 * see http://www.math.keio.ac.jp/~matumoto/emt.html for more info.
 * The range functions return a value in the intervall [begin, end).
 * int          -> [0..2^32-1]
 * int_range    -> [begin..end-1]
 * double       -> [0..1)
 * double_range -> [begin..end)
 */

GRand*  g_rand_new_with_seed   (guint32     seed);
GRand*  g_rand_new             (void);
void    g_rand_free            (GRand      *rand);

void    g_rand_set_seed        (GRand      *rand,
                                guint32     seed);

#define g_rand_boolean(rand) (g_rand_int ((rand)) & (1<<15))

guint32 g_rand_int             (GRand      *rand);
gint32  g_rand_int_range       (GRand      *rand,
                                gint32      begin,
                                gint32      end);
gdouble g_rand_double          (GRand      *rand);
gdouble g_rand_double_range    (GRand      *rand,
                                gdouble     begin,
                                gdouble     end);

void    g_random_set_seed      (guint32     seed);

#define g_random_boolean() (g_rand_boolean ((rand)))

guint32 g_random_int           (void);
gint32  g_random_int_range     (gint32      begin,
                                gint32      end);
gdouble g_random_double        (void);
gdouble g_random_double_range  (gdouble     begin,
                                gdouble     end);

G_END_DECLS

#endif /* __G_RAND_H__ */
